InlineNode

Enum InlineNode 

pub enum InlineNode {
    Plain {
        text: String,
        annotations: Vec<Annotation>,
    },
    Strong {
        content: InlineContent,
        annotations: Vec<Annotation>,
    },
    Emphasis {
        content: InlineContent,
        annotations: Vec<Annotation>,
    },
    Code {
        text: String,
        annotations: Vec<Annotation>,
    },
    Math {
        text: String,
        annotations: Vec<Annotation>,
    },
    Reference {
        data: ReferenceInline,
        annotations: Vec<Annotation>,
    },
}
Inline node variants supported by the initial flat inline parser.

All variants include an annotations field for attaching metadata. Post-processors can populate this field when transforming inline content (e.g., parsing math to MathML).

Variants



Plain

Plain text segment with no formatting.

Fields

text: String
annotations: Vec<Annotation>


Strong

Strong emphasis delimited by *.

Fields

annotations: Vec<Annotation>


Emphasis

Emphasis delimited by _.

Fields

annotations: Vec<Annotation>


Code

Inline code delimited by `.

Fields

text: String
annotations: Vec<Annotation>


Math

Simple math span delimited by #.

Fields

text: String
annotations: Vec<Annotation>


Reference

Reference enclosed by square brackets.

Fields

annotations: Vec<Annotation>

Implementations

Source

impl InlineNode

pub fn plain(text: String) -> Self

Creates a plain text node without annotations.

pub fn code(text: String) -> Self

Creates a code node without annotations.

pub fn math(text: String) -> Self

Creates a math node without annotations.

pub fn strong(content: InlineContent) -> Self

Creates a strong node without annotations.

pub fn emphasis(content: InlineContent) -> Self

Creates an emphasis node without annotations.

pub fn reference(data: ReferenceInline) -> Self

Creates a reference node without annotations.

pub fn as_plain(&self) -> Option<&str>

Returns the plain text from this node when available.

pub fn children(&self) -> Option<&InlineContent>

Returns nested inline content for container nodes (strong/emphasis).

pub fn is_plain(&self) -> bool

Returns true when this node is plain text.

pub fn annotations(&self) -> &[Annotation]

Returns a reference to this node’s annotations.

pub fn annotations_mut(&mut self) -> &mut Vec<Annotation>

Returns a mutable reference to this node’s annotations.

pub fn with_annotation(self, annotation: Annotation) -> Self

Adds an annotation to this node.

pub fn with_annotations(self, annotations: Vec<Annotation>) -> Self

Adds multiple annotations to this node.