pub struct Paragraph {
pub lines: Vec<ContentItem>,
pub annotations: Vec<Annotation>,
pub location: Range,
}Expand description
A paragraph represents a block of text lines
Fields
lines: Vec<ContentItem>Lines stored as ContentItems (each a TextLine wrapping TextContent)
annotations: Vec<Annotation>location: RangeImplementations
Sourceimpl Paragraph
impl Paragraph
pub fn new(lines: Vec<ContentItem>) -> Self
pub fn from_line(line: String) -> Self
Sourcepub fn from_line_at(line: String, location: Range) -> Self
pub fn from_line_at(line: String, location: Range) -> Self
Create a paragraph with a single line and attach a location
pub fn text(&self) -> String
Sourcepub fn annotations(&self) -> &[Annotation]
pub fn annotations(&self) -> &[Annotation]
Annotations attached to this paragraph.
Sourcepub fn annotations_mut(&mut self) -> &mut Vec<Annotation>
pub fn annotations_mut(&mut self) -> &mut Vec<Annotation>
Mutable access to paragraph annotations.
Sourcepub fn iter_annotations(&self) -> Iter<'_, Annotation>
pub fn iter_annotations(&self) -> Iter<'_, Annotation>
Iterate over annotation blocks in source order.
Sourcepub fn iter_annotation_contents(&self) -> impl Iterator<Item = &ContentItem>
pub fn iter_annotation_contents(&self) -> impl Iterator<Item = &ContentItem>
Iterate over all content items nested inside attached annotations.