pub struct SourceLocation { /* private fields */ }Expand description
Provides fast conversion from byte offsets to line/column positions
Implementations
Sourceimpl SourceLocation
impl SourceLocation
Sourcepub fn byte_to_position(&self, byte_offset: usize) -> Position
pub fn byte_to_position(&self, byte_offset: usize) -> Position
Convert a byte offset to a line/column position
Sourcepub fn byte_range_to_ast_range(&self, range: &ByteRange<usize>) -> Range
pub fn byte_range_to_ast_range(&self, range: &ByteRange<usize>) -> Range
Convert a byte range to a location
Sourcepub fn line_count(&self) -> usize
pub fn line_count(&self) -> usize
Get the total number of lines in the source
Sourcepub fn line_start(&self, line: usize) -> Option<usize>
pub fn line_start(&self, line: usize) -> Option<usize>
Get the byte offset for the start of a line