Lexplore

Struct Lexplore 

pub struct Lexplore;
Interface for loading per-element test sources

Implementations

Source

impl Lexplore

pub fn load(element_type: ElementType, number: usize) -> DocumentLoader

Load an element file by type and number

Returns a DocumentLoader which provides transform shortcuts.

pub fn load_document(doc_type: DocumentType, number: usize) -> DocumentLoader

Load a document collection file by type and number

Returns a DocumentLoader which provides transform shortcuts.

pub fn from_path<P: AsRef<Path>>(path: P) -> DocumentLoader

Load from an arbitrary file path

Returns a DocumentLoader which provides transform shortcuts.

pub fn get_paragraph(number: usize) -> &'static Paragraph

Load a paragraph element file and return the paragraph directly

Example
let paragraph = Lexplore::get_paragraph(3);
assert!(paragraph.text().starts_with("Expected"));
pub fn get_list(number: usize) -> &'static List

Load a list element file and return the list directly

pub fn get_session(number: usize) -> &'static Session

Load a session element file and return the session directly

pub fn get_definition(number: usize) -> &'static Definition

Load a definition element file and return the definition directly

pub fn get_annotation(number: usize) -> &'static Annotation

Load an annotation element file and return the annotation directly

pub fn get_verbatim(number: usize) -> &'static Verbatim

Load a verbatim element file and return the verbatim block directly

pub fn paragraph(number: usize) -> DocumentLoader

Load a paragraph file (returns DocumentLoader for transforms)

pub fn list(number: usize) -> DocumentLoader

Load a list file (returns DocumentLoader for transforms)

pub fn session(number: usize) -> DocumentLoader

Load a session file (returns DocumentLoader for transforms)

pub fn definition(number: usize) -> DocumentLoader

Load a definition file (returns DocumentLoader for transforms)

pub fn annotation(number: usize) -> DocumentLoader

Load a annotation file (returns DocumentLoader for transforms)

pub fn verbatim(number: usize) -> DocumentLoader

Load a verbatim file (returns DocumentLoader for transforms)

pub fn document(number: usize) -> DocumentLoader

Load a document file (returns DocumentLoader for transforms)

pub fn benchmark(number: usize) -> DocumentLoader

Load a benchmark document (returns DocumentLoader for transforms)

pub fn trifecta(number: usize) -> DocumentLoader

Load a trifecta document (returns DocumentLoader for transforms)

pub fn list_numbers_for( element_type: ElementType, ) -> Result<Vec<usize>, ElementSourceError>

List all available numbers for a given element type