pub struct AnnotationAssertion<'a> { /* private fields */ }Implementations
Sourceimpl<'a> AnnotationAssertion<'a>
impl<'a> AnnotationAssertion<'a>
pub fn label(self, expected: &str) -> Self
pub fn data<F>(self, assertion: F) -> Selfwhere
F: FnOnce(DataAssertion<'a>),
pub fn parameter_count(self, expected: usize) -> Self
Sourcepub fn has_parameter(self, key: &str) -> Self
pub fn has_parameter(self, key: &str) -> Self
Assert that a parameter with the given key exists (any value)
Sourcepub fn no_parameter(self, key: &str) -> Self
pub fn no_parameter(self, key: &str) -> Self
Assert that a parameter with the given key does NOT exist
Sourcepub fn has_parameter_with_value(self, key: &str, value: &str) -> Self
pub fn has_parameter_with_value(self, key: &str, value: &str) -> Self
Assert that a parameter with the given key has the expected value
Sourcepub fn parameter(
self,
index: usize,
expected_key: &str,
expected_value: &str,
) -> Self
pub fn parameter( self, index: usize, expected_key: &str, expected_value: &str, ) -> Self
Assert on a specific parameter by index
Sourcepub fn parameter_key(self, index: usize, expected_key: &str) -> Self
pub fn parameter_key(self, index: usize, expected_key: &str) -> Self
Assert that parameter at given index has the expected key (any value)
pub fn child_count(self, expected: usize) -> Self
pub fn child<F>(self, index: usize, assertion: F) -> Selfwhere
F: FnOnce(ContentItemAssertion<'a>),