pub struct ContentItemAssertion<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ContentItemAssertion<'a>
impl<'a> ContentItemAssertion<'a>
Sourcepub fn assert_paragraph(self) -> ParagraphAssertion<'a>
pub fn assert_paragraph(self) -> ParagraphAssertion<'a>
Assert this item is a Paragraph and return paragraph-specific assertions
Sourcepub fn assert_session(self) -> SessionAssertion<'a>
pub fn assert_session(self) -> SessionAssertion<'a>
Assert this item is a Session and return session-specific assertions
Sourcepub fn assert_list(self) -> ListAssertion<'a>
pub fn assert_list(self) -> ListAssertion<'a>
Assert this item is a List and return list-specific assertions
Sourcepub fn assert_definition(self) -> DefinitionAssertion<'a>
pub fn assert_definition(self) -> DefinitionAssertion<'a>
Assert this item is a Definition and return definition-specific assertions
Sourcepub fn assert_annotation(self) -> AnnotationAssertion<'a>
pub fn assert_annotation(self) -> AnnotationAssertion<'a>
Assert this item is an Annotation and return annotation-specific assertions
Sourcepub fn assert_verbatim_block(self) -> VerbatimBlockkAssertion<'a>
pub fn assert_verbatim_block(self) -> VerbatimBlockkAssertion<'a>
Assert this item is a VerbatimBlock and return verbatim block-specific assertions