DocumentAssertion

Struct DocumentAssertion 

pub struct DocumentAssertion<'a> { /* private fields */ }

Implementations

Source

impl<'a> DocumentAssertion<'a>

pub fn title(self, expected: &str) -> Self

Assert the document title matches exactly

pub fn title_matches(self, matcher: TextMatch) -> Self

Assert the document title matches a pattern

pub fn title_is_empty(self) -> Self

Assert the document has no title (empty string)

pub fn has_title(self) -> Self

Assert the document has a non-empty title

pub fn item_count(self, expected: usize) -> Self

Assert the number of items in the document

pub fn item<F>(self, index: usize, assertion: F) -> Self

Assert on a specific item by index

pub fn root_location_starts_at( self, expected_line: usize, expected_column: usize, ) -> Self

Assert the root session location starts at the given line and column

pub fn root_location_ends_at( self, expected_line: usize, expected_column: usize, ) -> Self

Assert the root session location ends at the given line and column

pub fn root_location_contains(self, line: usize, column: usize) -> Self

Assert the root session location contains the given position

pub fn root_location_excludes(self, line: usize, column: usize) -> Self

Assert the root session location does NOT contain the given position

pub fn annotation_count(self, expected: usize) -> Self

pub fn annotation<F>(self, index: usize, assertion: F) -> Self