pub struct InlineAssertion { /* private fields */ }Implementations
Sourceimpl InlineAssertion
impl InlineAssertion
pub fn new(content: &TextContent, context: impl Into<String>) -> Self
Sourcepub fn starts_with(self, expectations: &[InlineExpectation]) -> Self
pub fn starts_with(self, expectations: &[InlineExpectation]) -> Self
Assert that the inline list starts with the provided expectations.
This mirrors the workflow described in the inline proposal: tests only need to check the prefix of the inline list for quick sanity checks.
Sourcepub fn nodes(&self) -> &[InlineNode]
pub fn nodes(&self) -> &[InlineNode]
Exposes the raw inline nodes for custom assertions.