pub struct Lexplore;Expand description
Interface for loading per-element test sources
Implementations
Sourceimpl Lexplore
impl Lexplore
Sourcepub fn load(element_type: ElementType, number: usize) -> DocumentLoader
pub fn load(element_type: ElementType, number: usize) -> DocumentLoader
Load an element file by type and number
Returns a DocumentLoader which provides transform shortcuts.
Sourcepub fn load_document(doc_type: DocumentType, number: usize) -> DocumentLoader
pub fn load_document(doc_type: DocumentType, number: usize) -> DocumentLoader
Load a document collection file by type and number
Returns a DocumentLoader which provides transform shortcuts.
Sourcepub fn from_path<P: AsRef<Path>>(path: P) -> DocumentLoader
pub fn from_path<P: AsRef<Path>>(path: P) -> DocumentLoader
Load from an arbitrary file path
Returns a DocumentLoader which provides transform shortcuts.
Sourcepub fn get_paragraph(number: usize) -> &'static Paragraph
pub fn get_paragraph(number: usize) -> &'static Paragraph
Sourcepub fn get_list(number: usize) -> &'static List
pub fn get_list(number: usize) -> &'static List
Load a list element file and return the list directly
Sourcepub fn get_session(number: usize) -> &'static Session
pub fn get_session(number: usize) -> &'static Session
Load a session element file and return the session directly
Sourcepub fn get_definition(number: usize) -> &'static Definition
pub fn get_definition(number: usize) -> &'static Definition
Load a definition element file and return the definition directly
Sourcepub fn get_annotation(number: usize) -> &'static Annotation
pub fn get_annotation(number: usize) -> &'static Annotation
Load an annotation element file and return the annotation directly
Sourcepub fn get_verbatim(number: usize) -> &'static Verbatim
pub fn get_verbatim(number: usize) -> &'static Verbatim
Load a verbatim element file and return the verbatim block directly
Sourcepub fn paragraph(number: usize) -> DocumentLoader
pub fn paragraph(number: usize) -> DocumentLoader
Load a paragraph file (returns DocumentLoader for transforms)
Sourcepub fn list(number: usize) -> DocumentLoader
pub fn list(number: usize) -> DocumentLoader
Load a list file (returns DocumentLoader for transforms)
Sourcepub fn session(number: usize) -> DocumentLoader
pub fn session(number: usize) -> DocumentLoader
Load a session file (returns DocumentLoader for transforms)
Sourcepub fn definition(number: usize) -> DocumentLoader
pub fn definition(number: usize) -> DocumentLoader
Load a definition file (returns DocumentLoader for transforms)
Sourcepub fn annotation(number: usize) -> DocumentLoader
pub fn annotation(number: usize) -> DocumentLoader
Load a annotation file (returns DocumentLoader for transforms)
Sourcepub fn verbatim(number: usize) -> DocumentLoader
pub fn verbatim(number: usize) -> DocumentLoader
Load a verbatim file (returns DocumentLoader for transforms)
Sourcepub fn document(number: usize) -> DocumentLoader
pub fn document(number: usize) -> DocumentLoader
Load a document file (returns DocumentLoader for transforms)
Sourcepub fn benchmark(number: usize) -> DocumentLoader
pub fn benchmark(number: usize) -> DocumentLoader
Load a benchmark document (returns DocumentLoader for transforms)
Sourcepub fn trifecta(number: usize) -> DocumentLoader
pub fn trifecta(number: usize) -> DocumentLoader
Load a trifecta document (returns DocumentLoader for transforms)
Sourcepub fn list_numbers_for(
element_type: ElementType,
) -> Result<Vec<usize>, ElementSourceError>
pub fn list_numbers_for( element_type: ElementType, ) -> Result<Vec<usize>, ElementSourceError>
List all available numbers for a given element type