pub struct DocumentAssertion<'a> { /* private fields */ }Implementations
Sourceimpl<'a> DocumentAssertion<'a>
impl<'a> DocumentAssertion<'a>
Sourcepub fn title_matches(self, matcher: TextMatch) -> Self
pub fn title_matches(self, matcher: TextMatch) -> Self
Assert the document title matches a pattern
Sourcepub fn title_is_empty(self) -> Self
pub fn title_is_empty(self) -> Self
Assert the document has no title (empty string)
Sourcepub fn item_count(self, expected: usize) -> Self
pub fn item_count(self, expected: usize) -> Self
Assert the number of items in the document
Sourcepub fn item<F>(self, index: usize, assertion: F) -> Selfwhere
F: FnOnce(ContentItemAssertion<'a>),
pub fn item<F>(self, index: usize, assertion: F) -> Selfwhere
F: FnOnce(ContentItemAssertion<'a>),
Assert on a specific item by index
Sourcepub fn root_location_starts_at(
self,
expected_line: usize,
expected_column: usize,
) -> Self
pub fn root_location_starts_at( self, expected_line: usize, expected_column: usize, ) -> Self
Assert the root session location starts at the given line and column
Sourcepub fn root_location_ends_at(
self,
expected_line: usize,
expected_column: usize,
) -> Self
pub fn root_location_ends_at( self, expected_line: usize, expected_column: usize, ) -> Self
Assert the root session location ends at the given line and column
Sourcepub fn root_location_contains(self, line: usize, column: usize) -> Self
pub fn root_location_contains(self, line: usize, column: usize) -> Self
Assert the root session location contains the given position
Sourcepub fn root_location_excludes(self, line: usize, column: usize) -> Self
pub fn root_location_excludes(self, line: usize, column: usize) -> Self
Assert the root session location does NOT contain the given position
pub fn annotation_count(self, expected: usize) -> Self
pub fn annotation<F>(self, index: usize, assertion: F) -> Selfwhere
F: FnOnce(AnnotationAssertion<'a>),